"""
The core mixin
"""

class CoreMixin:
    """ """

    @staticmethod
    def get_name():
        """ """
        return "core"

    @staticmethod
    def get_renderer(document):
        """

        Args:
          document: 

        Returns:

        """
        return None

    @staticmethod
    def apply_to(node):
        """

        Args:
          node: 

        Returns:

        """
        # all functions have been moved to ContentNode
        pass
